$.i18n().load({
    "sr-Cylr": {
        "regex_title": "Регуларни израз",
        "flag_title": "Опције",
        "text_title": "Тест текст",
        "button_text": "Прикажи решење",
        "button_test" : "Упореди са решењем",
        "correct": "Тачно",
        "incorrect" : "Нетачно",
    }
})